RequiredError

Struct RequiredError 

#[non_exhaustive]
pub struct RequiredError { pub field: &'static str, }
Error returned by TryFrom implementations generated by typex!(Target = T!).

Carries the name of the first Option-wrapped field that was None when attempting to convert a Partial type back into its Required form.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
field: &'static str

Name of the field that was None.